#
# spec file for package hdparm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hdparm
Version:        9.65
Release:        3.3
Summary:        A Program to get and set hard disk parameters
License:        SUSE-Permissive
Group:          Hardware/Other
URL:            https://sourceforge.net/projects/hdparm/
Source:         https://downloads.sourceforge.net/project/hdparm/hdparm/hdparm-%{version}.tar.gz
Patch1:         hdparm-nostrip.patch
Patch2:         hdparm-wiper-warn.patch
Patch3:         hdparm-leak-fix.patch
Patch4:         hdparm-9.43-fix-bashisms.patch
# https://sourceforge.net/p/hdparm/patches/52/
Patch5:         avoid-linux-includes.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(udev)
Requires(post): coreutils
Provides:       base:/sbin/hdparm

%description
A shell utility to access and tune the ioctl features of the Linux IDE
driver and IDE drives.

%prep
%setup -q
%patch -P 1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

%build
%make_build CFLAGS="%{optflags} -Wall -Wstrict-prototypes" LDFLAGS= CC="gcc"
cp -p wiper/README.txt README.wiper

%install
mkdir -p "%{buildroot}%{_mandir}/man8"
install -d "%{buildroot}/%{_sbindir}"
%make_install binprefix="%{_prefix}"
mv contrib/README contrib/README.contrib
install -d "%{buildroot}%{_libexecdir}/hdparm"
install -m 755 contrib/idectl "%{buildroot}%{_libexecdir}/hdparm"
install -m 755 contrib/ultrabayd "%{buildroot}%{_libexecdir}/hdparm"
install -m 755 wiper/wiper.sh "%{buildroot}/%{_sbindir}"
%if 0%{?suse_version} < 1550
mkdir -p "%{buildroot}/sbin"
ln -sf %{_sbindir}/wiper.sh "%{buildroot}/sbin"
ln -sf %{_sbindir}/hdparm "%{buildroot}/sbin"
%endif

%files
%license LICENSE.TXT
%doc Changelog README.acoustic contrib/README.contrib README.wiper
%{_mandir}/man8/hdparm.8%{?ext_man}
%if 0%{?suse_version} < 1550
/sbin/hdparm
/sbin/wiper.sh
%endif
%{_sbindir}/hdparm
%{_sbindir}/wiper.sh
%{_libexecdir}/hdparm

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Wed Sep 14 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to 9.65:
  * Fixed "hdparm --Istdin" to not attempt reading LOG data from a non-existent drive.
- Refresh avoid-linux-includes.patch
* Tue Aug  9 2022 Dirk Müller <dmueller@suse.com>
- add avoid-linux-includes.patch (bsc#1202212)
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 9.64:
  * fix truncated output buf with --Istdin
* Tue Jan 11 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to 9.63:
  * new --sanitize-overwrite-passes flag, courtesy Michal Grzedzicki.
  * "Plurals patch" from Martin Guy.
* Mon May 10 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 9.62:
  * work around unexpected sign-extending of left-shifted unsigned
    values by gcc
* Tue Apr 27 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 9.61:
  - fixes for --set-sector-size and reporting of physical/logical sector sizes
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 9.60:
  - support for ioSafe Solo with jMicron bridge, courtesy Matthias-Christian Ott.
  - decode more bits from id[69], courtesy Adrián Kálazi.
  - allow passing of custom LDFLAGS from the environment.
  - add new "static" target.
  - fix --dco-identify max sectors, courtesy of Paul Sultana.
  - get rid of leftover "unknown" variables from identify.c
  - fixed return values from get_log_page_data().
* Thu Nov 26 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Sun Feb 10 2019 josua.mayer97@gmail.com
- Update to 9.58
  * fix segfault with -I onr non-ATA drives.
* Thu Oct 18 2018 mvetter@suse.com
- Update to 9.57:
  * Added --set-sector-size flag, used to change logical sector
    size for drives which support multiple sector sizes.
  * Also updated various bits of hdparm to better cope with
    non-512 byte sectors.
  * Various other minor fixes/enhancements.
- Update hdparm-leak-fix.patch
* Fri Apr 20 2018 kstreitova@suse.com
- update to version 9.56
  * 9.56 - fixed byte order for --Istdout so that --Istdin can
    grok it
  - added --Iraw for raw binary output of IDENTIFY data
    to a file
  * 9.55 - added #include <sys/sysmacros.h> for major()/minor()
    macros
  * 9.54 - Partial revert of Jmicron changes, from Jan Friesse.
  * 9.53 - Read Drive Capacity fixes from Iestyn Walters.
  - SET MAX ADDRESS fixes from Tom Yan <tom.ty89@gmail.com>
  - added --security-prompt-for-password to --security-help
    output
  - fwdownload changes from Jihoon Lee.
* Wed Dec 13 2017 kstreitova@suse.com
- update to version 9.52
  * 9.52 - add support for Jmicron USB-SATA bridges
  * 9.51 - New --security-prompt-for-password flag for use with the
    various --security- actions
  - Makefile tweak
  - fix spelling/typos in man page and "removable"
  - fix spelling/typos in --sanitize-crypto-scramble
  - fix NULL password handling in --security-unlock
  * 9.50 - minor fixes for sanitize device stuff
  * 9.49 - add ACS-3 overprovisioning support
  - fix bug in display of security section and use updated
    erase-time values from ACS-3
  - increase timeout on fwdownload to 2 minutes
  - fix bugs from devslp patch
- run spec-cleaner
* Thu Aug  4 2016 kstreitova@suse.com
- remove 56-idedma.rules and idedma.sh as none of these scripts
  have any function whatsoever. They rely on the obsolete IDE
  drivers [bsc#991898]
- remove /etc/sysconfig/ide file [bsc#922659]
* Mon Jun 22 2015 kstreitova@suse.com
- update to version 9.48
  * 9.48 - fixed a number of output bugs due to the devslp patch
  * 9.47 - added devslp patch (IDENTIFY word 76) from David Woodhouse.
  - help and manpage fixes from Michal Minar.
  * 9.46 - fix compilation with "musl libc".
  - added "hex:aabbcc.." for binary security passwords.
  - return EIO when read_big_block() fails
  - use llabs() rather than abs() in identify.c
- use spec-cleaner
* Sat Jan 17 2015 p.drouand@gmail.com
- Update to version 9.45
  * fixed blocksize handling in fibmap code to use result from
    FIGETBSZ in more places
  * fixed divide by zero exception in geom.c
  * tidying up formatting in sgio.c
* Mon Dec  8 2014 jengelh@inai.de
- Use preferred download URL; replace only rpm shell vars with
  macros to go in line with the rest.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in ultrabayd and udev.idedma.sh scripts
- add patches:
  * hdparm-9.43-fix-bashisms.patch
* Fri Sep 19 2014 crrodriguez@opensuse.org
- Fix udev rules, broken script location, scriptlets
  macro usages..
* Sat Jul 19 2014 p.drouand@gmail.com
- Remove insserv dependency; the package doesn't contain any init
  script
* Tue Nov 27 2012 dimstar@opensuse.org
- Add pkgconfig(udev) BuildRequires: needed in order to dynamically
  extract the right folder for udev rules and scripts.
- Copy the udev rules to %%{_udevdir}, identified based on udev.pc.
- Add pkgconfig BuildRequires: needed, as we otherwise end up not
  having pkg-config in the build root, which we rely on to read
  the .pc file.
* Fri Nov 16 2012 puzel@suse.com
- update to hdparm-9.43
  - rearrange flag execution so that the idle/standby/sleep "now"
    flags are executed last.
* Mon Oct  1 2012 puzel@suse.com
- update to hdparm-9.42
  - fix ordering of -S -y flags
  - spelling, typo, and formatting fixes for manpage and others
  - set block-count to 1 for Security commands sent via SAT (sgio)
  - use FIGETBSZ to determine filesystem block size for fibmap -- needed for FAT
  - fix master password revcode handling
  - try and fix reg_flags (again!) for old IDE taskfile ioctls
  - fixed '&&' bug in dco_identify code
  - force sector dumps (read-sector, identify, ..) to use le16 output format
  - proper SCT identify info courtesy of Leonid Evdokimov <leon@darkk.net.ru>
  - updated raid1ext4trim.sh-1.5 script
  - avoid HDIO_GETGEO_BIG when possible (doesn't exist in
    linux-2.6.xx and beyond)
  - pad secure erase timeouts by 30minutes rather than 5minutes.
* Sat Feb 18 2012 rschweikert@suse.com
- fix license warning, set to SUSE-Permissive
* Wed Feb 15 2012 rschweikert@suse.com
- put binaries in /usr tree (UsrMerge) project
* Mon Feb  6 2012 puzel@suse.com
- update to hdparm-9.39
  - added -R flag to control Read-Write-Verify feature, courtesy of
    Gordan Bobic
  - nuked leftover sgio.c.orig file
* Sun Jan  8 2012 puzel@suse.com
- update to hdparm-9.38
  - updated wiper.sh to allow all SCSI_DISK major numbers
  - updated handing for very long SECURITY-ERASE times
  - added -J flag for wdidle3 set/get
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Mon Sep 19 2011 coolo@suse.com
- remove fragile _service file
* Wed Jan 26 2011 puzel@novell.com
- update to hdparm-9.37 (bnc#664825)
  - handle raid1 start_lba values, and show -1 for indeterminte
    raid start_lba values
  - abort --fibmap when start_lba is indeterminate
  - updated wiper.sh to fix a kink with hfsplus filesystems
  - updated wiper.sh to no longer rely on the obsolete "rdev"
    command
* Mon Nov 29 2010 puzel@novell.com
- update to hdparm-9.36
  - udpated raid1ext4trim.sh script to version 1.4
  - updated wiper.sh to support hfsplus and ntfs filesystem types,
    courtesy of Heiko Wegeler
  - updated wiper.sh with new flag to enable unattended operation,
    and handle SIGPIPE
  - updated manpage to indicate max sector range of 65335 for TRIM
* Thu Oct 21 2010 mseben@gmail.com
- update to hdparm-9.35
  * third go at fixing cdb issues, fixing -B flag.  Got it this time (finally).
- changes in hdparm-9.34
  * fix bad/missing cdb transfer length field for IDENTIFY and some other commands
* Tue Oct  5 2010 puzel@novell.com
- update to hdparm-9.33
  * fix AHCI issues in sg16(): don't ask for sense_data
    on DATA-xfer commands
  * fix compiler warnings on old systems
  * fixed compilation on old systems lacking __be16
* Fri Sep 24 2010 puzel@novell.com
- update to hdparm-9.32
  * fix b0rked (since 9.27?) SET_FEATURES commands; eg. -B, -M, etc..
* Wed Sep 15 2010 puzel@novell.com
- update to hdparm-9.30
  * report word[105] in -I :  max 512-byte blocks of range-data
    per DSM/Trim command
  * fix wiper.sh/hdparm to use only as many LBA ranges per TRIM as
    the drive can handle
  * manpage / help-text cleanups from Benno Schulenberg
    <bensberg@justemail.net>
* Thu Jul 22 2010 puzel@novell.com
- update to hdparm-9.29
  * add --offset for use with -t, to get timings from middle/end
    of drive,
  * restrict --trim-sector-ranges-stdin to small TRIM commands on
    most drives
  * fix w62 bug in -I
  * dump all data bytes with --verbose
  * warn about bad/missing sense data, but continue regardless
  * show in/out data[] separately with --verbose
  * Add reporting to -I for sata3 signaling speed.
  * force use of ATA_16 for all commands to ATAPI devices.
  * supply a sector count of "1" for IDENTIFY commands, to
    satisfy buggy USB3 bridges.
* Wed Mar 10 2010 mseben@novell.com
  Update to hdparm-9.28:
  * check for EBADE for IDE/ATAPI compatibility with recent kernels
  * always issue both methods when setting DVD speed with -E
  * use /usr/sbin/rdev to find rootdev in wiper.sh
  * fix reporting of Sector-0 offset, from Martin Petersen
  * first crack at decoding the "WD Idle3" vendor-unique command (disabled by default)
* Wed Sep 16 2009 mseben@novell.com
- added leak-fix.patch [bnc#538942]
* Tue Sep 15 2009 garloff@suse.de
- Install wiper.sh and its README; display appropriate warnings
- Update to hdparm-9.27:
  * Update wiper.sh to 2.3
  * Fix interaction with old IDE drivers
- Update to hdparm-9.26:
  * Update wiper.sh to 2.2
  * Fix handling of model names with spaces in hdparm -i
  * bugfix for --security-erase-enhanced
  * set _FILE_OFFSET_BITS in geom.c
  * added reporting for "Deterministic read ZEROs after TRIM" feature
- Update to hdparm-9.25:
  * slightly tidier output from --trim-* commands
  * restrict --trim-sector-ranges-stdin to limit from
    /sys/block/sd?/queue/max_sectors_kb
  * updated wiper.sh to use --trim-sector-ranges-stdin
- Update to hdparm-9.24:
  * fixed malloc() bug in --trim-sector-ranges
- Update to hdparm-9.23:
  * minor cosmetic changes in fibmap.c
  * added --trim-sector-ranges-stdin for wiper.sh-2.0
  * tightened up excess-args checking on a number of flags
  * added name to version line
* Wed Aug 12 2009 mseben@suse.cz
- updated to hdparm 9.22
  - added fsync() call inside --fallocate
  - fixed fibmap.c to work around an observed ext4 bug with FIEMAP's "LAST" flag
  - added detailed comments to wiper.sh
  - more rework of wiper.sh, added xfs support, added generic online support
  - twiddled the code in geom.c slightly
  - cosmetic changes in fibmap.c and the manpage description of --fibmap
  - added kernel patch for compat_ioctl::fiemap support
- version hdparm 9.21
  - fixes and (big) speedups to wiper.sh (v1.2) script
- version hdparm 9.20
  - unified the online/offline wiper scripts into a single wiper.sh script
  - fixed bug whereby the wiper scripts generated command-lines too long for bash
  - fixed non-zero exit status from successful --trim-sector-ranges
  - reimplemented --trim-sector-ranges to use sg16() directly, with aligned data
  - allow wiper scripts to issue TRIM with up to 255 sectors of LBA-range data
  - added kernel patch file for sil24 protocol fix, needed for wiper/TRIM
  - cosmetic updates to the wiper scripts
  - fixed confirmation prompt text for --trim-sector-ranges
  - fixed manpage example for --trim-sector-ranges
  - removed some dead code (previously #if 0'd)
* Fri Jul 31 2009 mseben@suse.cz
- update to version 9.19
  - fixed compile of fallocate.c on older systems
  - fixed man page description of --fallocate (parameters were reversed)
- version 9.18
  - fixed -E (set cd/dvd streaming speed)
  - updated man page for --fallocate, indicating ext4/xfs only
  - bumped max_sectors to 8000000 per TRIM in wiper scripts
  - s/awk/$GAWK/ in wiper.sh.online script
- version 9.17
  - added wiper/ subdirectory with preliminary SSD-wiper (TRIM) scripts
  - nuked kernel_patches/ subdirectory
  - Capitalize first word of each line of help output
  - added ioctl(FIEMAP) support to --fibmap
  - added --fallocate flag
  - added --trim-sector-ranges flag
  - removed --trim-sectors flag
  - removed --fibmap-sector flag
  - first cut at wiper.sh script, to trim unused space on a non-rw ext[234] filesystem
  - embed VERSION string for easier digging out with strings(1)
* Fri Jul 17 2009 mseben@suse.cz
- update to version 9.16
  - new protocol-specific forms of --fwdownload flags
  - added --trim-sectors flag
  - prevent segfaults when get_identify_data() fails
  - added full word69 features reporting for -I
  - added BuffSize=unknown to -i
* Wed Jun 17 2009 mseben@suse.cz
- dropped fix_standby object file from package (it breaks build
  process bnc#513109)
* Mon Apr 20 2009 mseben@suse.cz
- update to version 9.15
  - fix sgio.c LBA48 bugs on big-endian machines
  - fix -m to work with libata
  - added development snapshot of --erase-sectors (256) command (do not use)
  - added development snapshot of --format-track  (256) command (do not use)
- version 9.14
  - display DSM determinate/indeterminate TRIM support in -I output
  - tidy output of CFA features from -I
  - switch back to O_RDONLY for everything, to keep Debian/udevd happy
* Sun Apr 19 2009 kay.sievers@novell.com
- do not try to set DMA for libata devices - it will not do anything
- move rules file to /lib/udev/rules.d
* Mon Mar 23 2009 mseben@suse.cz
- update to version 9.13
  * fix O_DIRECT (--direct) for arch's other than x86
  * strip leading/trailing spaces from -i model/fwrev/serno strings
* Mon Mar  2 2009 mseben@suse.cz
- update to version 9.12
  * added logical/physical sector size reporting
  * updated -I output with SATA-2.6 additions
  * support APM level retrieval with -B flag
  * updated -C output to match ATA8
  * added "form factor" and "rotation" display to -I, courtesy of Martin K.Petersen.
* Mon Feb 16 2009 mseben@suse.cz
- update to version 9.11
  * switch back to ATA_16 by default: required by libata for ATAPI devices
  * add --prefer-ata12 to force use of ATA_12 when needed (some USB enclosures)
* Fri Jan 30 2009 mseben@suse.cz
- update to version 9.10
  * try and improve CF card detection
  * fix display of mwdma modes 3,4 for CF cards
* Mon Jan 26 2009 mseben@suse.cz
- update to version 9.9
  * recalculate cyls when kernel returns a truncated value
* Thu Jan 15 2009 mseben@suse.cz
- update to version 9.8
  * fix -N  to correctly use top 4 LBA bits on non-LBA48 drives
- version 9.7
  * FIX RATHER NASTY LBA48/LBA28 CONFUSION BUGS
  * use ATA_12 by default (helps USB), ATA_16 only when needed for LBA48
* Tue Jan  6 2009 mseben@suse.cz
- update to version 9.6
  * fix -N for 1.5TB drives (from Justin Maggard)
- version 9.5
  * byteswap ID strings for fwdownload workarounds
  * Makefile fixes for $(STRIP) from Wolfram Sang
- version 9.4
  * nuked --fwdownload80 in favour of model-specific workarounds
  * use mlock() instead of MAP_POPULATE in fwdownload.c
  * issue SET_STREAMING command as part of -E (for newer CD/DVD drives)
    courtesy of Thomas Orgis <thomas@orgis.org>
    and Thomas Fritzsche" <tf@noto.de>.
- version 9.3
  * new --idle-immediate and --idle-unload commands
- version 9.2
  * fix WWN output from -I
- version 9.1
  * tidy up output from --dco-identify, add more info to manpage
  * add kernel (device driver) bug detection/warning to -N output
- version 9.0
  * update debian directory contents
  * add --dco-freeze, --dco-identify, --dco-restore flags
  * fix sgio.c to be more clever around the lba28 boundary
  * add supposedly obsolete "cache/buffer size" reporting to -I
  * new --fwdownload flag
  * fix error reporting from sg16().
  * dump entire returned sense desc[] in sgio.c with --verbose
- rewritten hdparm-*-nostrip.patch for version 9.6
* Tue Aug 12 2008 lmichnovic@suse.cz
- update to version 8.9
  * Add compatibility for /sys/block/ symlinks, as seen on some
  distro kernels.
- version 8.8
  * Fixed bugs in -r, -a, and -Q flags.
- version 8.7
  * fixes to permit building against older kernels which lack SG_IO
  * added build script for empeg systems
  * removed -R, -U flags: kernel support is broken and being removed
  * fixed IO_support output
  * prevent error messages from default flags
  * added sysfs.c, geom.c, fibmap.c
  * use sysfs for device start_lba/nsectors values whereever
  possible (for >= 2TB drives)
  * new standalone --fibmap and --fibmap-sector flags
  * converted -Q to access the queue_depth attribute from sysfs
  (now works for SATA!)
  * fixed readonly issue with optical drives that some people
  noticed
* Wed Feb 27 2008 lmichnovic@suse.cz
- update to version 8.6
  * add partition safeguards to r/w sector and make_bad_sector
* Mon Feb 25 2008 lmichnovic@suse.cz
- update to version 8.5
  * fix u8->u16 bug in security commands for all of 8.x series, from
  Christian Franke
  * try and quiet errors from flush_buffer_cache()
  (obsoletes *silence.patch)
* Wed Feb 20 2008 lmichnovic@suse.cz
- *silence.patch changed after discussion with author
* Wed Feb 20 2008 lmichnovic@suse.cz
- update to 8.4
  * Changes since 8.3
  - Fix --write-sector breakage from v8.3
  * Changes since 8.2
  - fixed -i display for udma6
  - try and exit with errno on fail paths, from Ladislav Michnovic
  obsoletes *err_return.patch
* Tue Feb 19 2008 lmichnovic@suse.cz
- rewritten *silence.patch, *err_return.patch
* Tue Feb 19 2008 lmichnovic@suse.cz
- update to version 8.2
- Fixed sector ops (and other stuff) to work with non-libata IDE
  driver again.
  * Changes since 8.1
  - clear feat register for safety with SET_MAX_ADDRESS command
  - add note to manpage regarding possible -N transient failures
  - IDE_TASKFILE bug fixes and cleanups: works with old IDE driver
  - fix misreporting of dma modes on some SATA-ATAPI bridged drives
* Mon Feb 18 2008 lmichnovic@suse.cz
- update to version 8.1
  * Changes since 8.0
  - fixed -U parameter bug
  - added ATA8 minor revision info to -I, courtesy of chrfranke
  - added WorldWideNumber to -I, courtesy of Raksac
  * Changes since 7.7
  - added --make-bad-sector to deliberately create a media error
  - added --write-sector (aka. --repair-sector) to repair a media
  error
  - added --read-sector to test for a media error
  - Makefile dependency tweaks
  - added -N (get/set max address/HPA) flag
  - fixed LBAsects output from -i to use LBA48 values when
  available
  - fixed alternate opcode for SLEEPNOW
  - lots of changes/fixes to sgio.c to support more commands
  - add detection of buggy Sandisk 16MB CF card
  - fixed tf_to_lba() bug, courtesy of Jakub Bogusz
* Fri Nov 30 2007 ro@suse.de
- added sd* to udev rule (#340039)
* Fri Aug 10 2007 ro@suse.de
- update to 7.7
  - fixed bug whereby old data was shown after settings changed (eg. with -W0)
  - removed old notes about a "correction factor" from man page -tT descriptions
  - retry open with O_RDONLY if O_RDWR fails with errno==EROFS
* Tue Jun 19 2007 ro@suse.de
- update to 7.6
  - added -F flag to flush on-drive write cache buffer
  - replaced use of shm* functions with of mmap()/mlock()
  - removed gcc -Wextra flag --> unsupported on Debian Sarge
  - re-allow use of --security-freeze in combination with other flags
* Thu Jun  7 2007 ro@suse.de
- update to 7.5
  - beef up warnings for -s1 flag, as people seem to be ignoring them
* Thu May 31 2007 ro@suse.de
- update to 7.4
  - ignore ENOTTY response from DRIVE_CMD(NULL)
  - decode CFA advanced timing information
* Thu May 24 2007 schwab@suse.de
- fix_standby is x86-only.
* Wed May 16 2007 ro@suse.de
- fix lint problems
  - install contrib scripts to /usr/lib/hdparm
  - mark udev file as config
  - fix permissions for fillup-template
* Mon Apr 30 2007 schwab@suse.de
- Don't strip binaries.
* Mon Apr 30 2007 ro@suse.de
- update to 7.3
  - fixed spelling of --drq-hsm-error in -h output
  - fixed SG_IO CDB[2] bits for better SAT compliance
  - fixed version number (v7.2 has "7.1" as version, doh!)
  - added #ifdef around use of BLKGETSIZE64
  - manpage updated
* Sun Apr 29 2007 ro@suse.de
- update to 7.2
  - tweak -C
  - added more debug info from --verbose
  - added --drq-hsm-error to test libata EH (VERY DANGEROUS, do not use)
  - fixed breakage when used with old IDE driver
* Sun Apr 29 2007 ro@suse.de
- update to 7.1
  - big-endian fixes for -I, --Istdin, --Istdout
  - cody tidying in sgio.c
  - updated help/manpage for -v
  - marked -s1 as (DANGEROUS)
- hdparm-7.0
  - new command-line parser
  - allow any chars (except 0x00) in security passwords
  - fixed -s manpage format error
  - updated -W manpage description
  - major internal rework in hdparm.c
  - added SET_FEATURES subcommand 0x07 to the -s0 sequence
    (the kernel will eventually have to do this automatically)
  - fixed duplicate display of udma modes 3,4,5 with -i
  - added Timed-Command-Completion (TLC) data for -I
  - added support for SG_IO (SAT) ATA_16 command transport
  - ignore case for longargs (eg. --istdout or --Istdout)
  - remove dependencies on <linux/hdreg.h>
  - added query wcache (-W)
  - enhanced query acoustic (-M)
  - added kernel_patches directory with patches for ATAPI support
- disable acoustic patch (surrounding code changed)
* Sat Oct 28 2006 aj@suse.de
- Update to version 6.9, changes since 6.6 are:
  * added -s flag to control power-up in standby
  * make --Istdin more robust
  * added -I recognition of SMART Command Transport (SCT)
  * fix X2 over-reporting of -T results
  * add udma 3/4/5 modes to the -i results
  * improve parsing/operation of --Istdin function
  * don't default to "-v" when only new "--" longopts are used.
  * calculate integrity word if not correct
  * remove used code/parameter from identify()
  * fix "(null)" strings from the "Drive conforms to" line of -I
  * tidied up usage of prefix vars in Makefile
  * fix bug in -C implementation
  * new -H flag for (Hitachi) drive temperature
* Sun Jun 11 2006 ro@suse.de
- update to version 6.6
  - manpage updates / corrections.
  - fixed bug in -C code.
  - major updates to bring -I information up to current specs.
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 ro@suse.de
- moved udev helper script to /lib/udev
* Tue Oct 25 2005 ro@suse.de
- update to version 6.3
* Fri Oct  7 2005 ro@suse.de
- added udev rule 56-idedma.rules
- moved sysconfig/ide from aaa_base to this package
  (and all the legacy postinstall code with it)
* Mon Apr 18 2005 ro@suse.de
- update to 6.1
* Tue Mar  8 2005 ro@suse.de
- use HDIO_SET_ACOUSTIC
* Fri Feb 11 2005 ro@suse.de
- update to 5.9
* Wed Feb  2 2005 ro@suse.de
- fix set acoustic (#48595)
* Fri Nov  5 2004 ro@suse.de
- update to 5.8
- remove-dup-swap.patch has been merged upstream
* Wed Oct 20 2004 ro@suse.de
- silence errors for BLKFLSBUF (#45057)
* Tue Oct 12 2004 ro@suse.de
- added contrib files to doc (#47105)
* Sat Sep  4 2004 ro@suse.de
- update to 5.7
- removed obsolete lvm patch
- recreated err_return patch again
* Tue Aug 17 2004 ro@suse.de
- update to 5.6
- recreated err_return patch
- readahead.patch is obsolete
* Wed May 12 2004 meissner@suse.de
- Removed duplicated byte swapping on big endian, it
  is no longer needed. (SUSE#39628/LTC#7961)
* Tue Feb  3 2004 ro@suse.de
- update to hdparm-5.5
- added limited support for SCSI(-controlled) CDROM/optical drives
* Tue Jan 27 2004 ro@suse.de
- rename variable readahead (glibc using this as a function)
* Thu Nov  6 2003 ro@suse.de
- added README.acoustic (#32917)
* Mon Oct 20 2003 ro@suse.de
- use defattr
- don't build as root
* Sun Jul  6 2003 ro@suse.de
- update to 5.4 with new timing code
* Tue Jun  3 2003 olh@suse.de
- add hdparm-5.3-dump_identity-endian.dif
  do not swap the id->cur_capacity0/1 values in userland
* Mon May 12 2003 ro@suse.de
- define LVM_BLK_MAJOR if not defined
* Wed Mar 26 2003 ro@suse.de
- fix timing test for large disks (#25861)
* Wed Mar 12 2003 ro@suse.de
- added patch to return an error for most failed ioctls
  (not all, because cdroms always fail for e.g. HDIO_GETGEO)
* Wed Nov 27 2002 ro@suse.de
- update (v5.3 endian fixes, other stuff)
* Thu Aug  1 2002 ro@suse.de
- update to 5.2
  . updated -Q to take queue depth as parameter value
  . formatting fixes for -I from various people
  . updated -I to most recent ATA6 draft standard
  . various compile fixes
* Thu Apr 25 2002 ro@suse.de
- added patch from axboe to make TCQ work
* Thu Apr 25 2002 ro@suse.de
- up to vanilla hdparm-4.7
- use buildroot
* Tue Sep  4 2001 ro@suse.de
- update to 4.1 (mostly merged changes from andre's patch)
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Thu Mar 15 2001 ro@suse.de
- split from base
